Currently mesa searches for two different environment variables,
LIBGL_DRIVERS_PATH and GBM_DRIVERS_PATH. The first is used for search
for DRI drivers in every case except GBM, and the latter is used
exclusively for setting GBM drivers. This patch simplifies things by
having just one variable to set.

Signed-off-by: Dylan Baker <baker.dyla...@gmail.com>
---
 src/gbm/backends/dri/gbm_dri.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/gbm/backends/dri/gbm_dri.c b/src/gbm/backends/dri/gbm_dri.c
index 347bc99..9d9d1c4 100644
--- a/src/gbm/backends/dri/gbm_dri.c
+++ b/src/gbm/backends/dri/gbm_dri.c
@@ -212,8 +212,8 @@ dri_load_driver(struct gbm_dri_device *dri)
 
    search_paths = NULL;
    if (geteuid() == getuid()) {
-      /* don't allow setuid apps to use GBM_DRIVERS_PATH */
-      search_paths = getenv("GBM_DRIVERS_PATH");
+      /* don't allow setuid apps to use LIBGL_DRIVERS_PATH */
+      search_paths = getenv("LIBGL_DRIVERS_PATH");
    }
    if (search_paths == NULL)
       search_paths = DEFAULT_DRIVER_DIR;
-- 
2.0.0

_______________________________________________
mesa-dev mailing list
mesa-dev@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/mesa-dev

Reply via email to